@@ -1,4 +1,4 @@
-/* 
+/*
  * tkFocus.c --
  *
  *	This file contains procedures that manage the input
@@ -121,12 +121,12 @@ static void		SetFocus _ANSI_ARGS_((TkWindow *winPtr, int force));
  */
 
 int
-Tk_FocusObjCmd(clientData, interp, argc, argv)
+Tk_FocusObjCmd(clientData, interp, argc, objv)
     ClientData clientData;	/* Main window associated with
 				 * interpreter. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int argc;			/* Number of arguments. */
-    Tcl_Obj *CONST args[];	/* Argument objects. */
+    Tcl_Obj *CONST objv[];	/* Argument objects. */
 {
     static char *focusOptions[] = {"-displayof", "-force", "-lastfor",
 				   (char *) NULL};
@@ -155,7 +155,7 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
      */
 
     if (argc == 2) {
-	windowName = Tcl_GetStringFromObj(args[1], (int *) NULL);
+	windowName = Tcl_GetStringFromObj(objv[1], (int *) NULL);
 	if (windowName[0] == 0) {
 	    return TCL_OK;
 	}
@@ -171,17 +171,17 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
 	}
     }
 
-    if (Tcl_GetIndexFromObj(interp, args[1], focusOptions, "option", 0,
+    if (Tcl_GetIndexFromObj(interp, objv[1], focusOptions, "option", 0,
 	    &index) != TCL_OK) {
     	return TCL_ERROR;
     }
     if (argc != 3) {
-	Tcl_WrongNumArgs(interp, 2, args, "window");
+	Tcl_WrongNumArgs(interp, 2, objv, "window");
 	return TCL_ERROR;
     }
     switch (index) {
       case 0: {        /* -displayof */
-	windowName = Tcl_GetStringFromObj(args[2], (int *) NULL);
+	windowName = Tcl_GetStringFromObj(objv[2], (int *) NULL);
 	newPtr = (TkWindow *) Tk_NameToWindow(interp, windowName, tkwin);
 	if (newPtr == NULL) {
 	    return TCL_ERROR;
@@ -193,7 +193,7 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
 	break;
       }
       case 1: {        /* -force */
-	windowName = Tcl_GetStringFromObj(args[2], (int *) NULL);
+	windowName = Tcl_GetStringFromObj(objv[2], (int *) NULL);
 	if (windowName[0] == 0) {
 	    return TCL_OK;
 	}
@@ -205,7 +205,7 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
 	break;
       }
       case 2: {        /* -lastfor */
-	windowName = Tcl_GetStringFromObj(args[2], (int *) NULL);
+	windowName = Tcl_GetStringFromObj(objv[2], (int *) NULL);
 	newPtr = (TkWindow *) Tk_NameToWindow(interp, windowName, tkwin);
 	if (newPtr == NULL) {
 	    return TCL_ERROR;
@@ -263,8 +263,8 @@ TkFocusFilterEvent(winPtr, eventPtr)
      * Design notes: the window manager and X server work together to
      * transfer the focus among top-level windows.  This procedure takes
      * care of transferring the focus from a top-level or wrapper window
-     * to the actual window within that top-level that has the focus. 
-     * We do this by synthesizing X events to move the focus around. 
+     * to the actual window within that top-level that has the focus.
+     * We do this by synthesizing X events to move the focus around.
      * None of the FocusIn and FocusOut events generated by X are ever
      * used outside of this procedure;  only the synthesized events get
      * through to the rest of the application.  At one point (e.g.
@@ -502,7 +502,7 @@ TkFocusFilterEvent(winPtr, eventPtr)
 	 * command was used to redirect the focus after it arrived at
 	 * dispPtr->implicitWinPtr)!!  In addition, we generate events
 	 * because the window manager won't give us a FocusOut event when
-	 * we focus on the root. 
+	 * we focus on the root.
 	 */
 
 	if ((dispPtr->implicitWinPtr != NULL)
