@@ -1,4 +1,4 @@
-/* 
+/*
  * tclTimer.c --
  *
  *	This file provides timer event management facilities for Tcl,
@@ -11,7 +11,6 @@
  *
  * RCS: @(#) $Id: tclTimer.c,v 1.2 1998/09/14 18:40:02 stanton Exp $
  */
-
 #include "tkPort.h"
 #include "Lang.h"
 
@@ -113,12 +112,14 @@ static int idleGeneration;	/* Used to fill in the "generation" fields
  * Prototypes for procedures referenced only in this file:
  */
 
+#ifndef TCL_EVENT_IMPLEMENT
 static void		AfterCleanupProc _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp));
 static void		AfterProc _ANSI_ARGS_((ClientData clientData));
 static void		FreeAfterPtr _ANSI_ARGS_((AfterInfo *afterPtr));
 static AfterInfo *	GetAfterEvent _ANSI_ARGS_((AfterAssocData *assocPtr,
 			    char *string));
+#else
 static void		InitTimer _ANSI_ARGS_((void));
 static void		TimerExitProc _ANSI_ARGS_((ClientData clientData));
 static int		TimerHandlerEventProc _ANSI_ARGS_((Tcl_Event *evPtr,
@@ -127,6 +128,9 @@ static void		TimerCheckProc _ANSI_ARGS_((ClientData clientData,
 			    int flags));
 static void		TimerSetupProc _ANSI_ARGS_((ClientData clientData,
 			    int flags));
+#endif
+#ifdef TCL_EVENT_IMPLEMENT
+
 
 /*
  *----------------------------------------------------------------------
@@ -203,6 +207,7 @@ TimerExitProc(clientData)
  *--------------------------------------------------------------
  */
 
+
 Tcl_TimerToken
 Tcl_CreateTimerHandler(milliseconds, proc, clientData)
     int milliseconds;		/* How many milliseconds to wait
@@ -230,7 +235,7 @@ Tcl_CreateTimerHandler(milliseconds, proc, clientData)
 	timerHandlerPtr->time.usec -= 1000000;
 	timerHandlerPtr->time.sec += 1;
     }
-    
+
     /*
      * Fill in other fields for the event.
      */
@@ -497,7 +502,7 @@ TimerHandlerEventProc(evPtr, flags)
 	if (timerHandlerPtr == NULL) {
 	    break;
 	}
-	    
+	
 	if ((timerHandlerPtr->time.sec > time.sec)
 		|| ((timerHandlerPtr->time.sec == time.sec)
 			&& (timerHandlerPtr->time.usec > time.usec))) {
@@ -690,6 +695,9 @@ TclServiceIdle()
     }
     return 1;
 }
+
+#else
+
 
 /*
  *----------------------------------------------------------------------
@@ -739,7 +747,7 @@ Tcl_AfterObjCmd(clientData, interp, objc, objv)
     static char *subCmds[] = {
         "cancel", "idle", "info",
         (char *) NULL};
-    
+
     if (objc < 2) {
 	Tcl_WrongNumArgs(interp, 1, objv, "option ?arg arg ...?");
 	return TCL_ERROR;
@@ -771,7 +779,7 @@ Tcl_AfterObjCmd(clientData, interp, objc, objv)
     /*
      * First lets see if the command was passed a number as the first argument.
      */
-    
+
     arg = Tcl_GetStringFromObj(objv[1], &length);
     if (isdigit(UCHAR(arg[0]))) {
 	if (Tcl_GetIntFromObj(interp, objv[1], &ms) != TCL_OK) {
@@ -826,7 +834,7 @@ Tcl_AfterObjCmd(clientData, interp, objc, objv)
 		    return TCL_ERROR;
 		}
 		if (objc == 3) {
-		    objPtr = objv[2];  
+		    objPtr = objv[2];
 		    Tcl_IncrRefCount(objPtr);
 		} else {
 		    objPtr = Tcl_ConcatObj(objc-2, objv+2);;
@@ -838,7 +846,7 @@ Tcl_AfterObjCmd(clientData, interp, objc, objv)
 		    }
 		}
 		if (afterPtr == NULL) {
-		    arg = Tcl_GetStringFromObj( objPtr, &length ); 
+		    arg = Tcl_GetStringFromObj( objPtr, &length );
 		    afterPtr = GetAfterEvent(assocPtr, arg);
 		}
 		if (objPtr != NULL) {
@@ -879,7 +887,7 @@ Tcl_AfterObjCmd(clientData, interp, objc, objv)
 	case 2:		/* info */
 	    if (objc == 2) {
 		char buffer[30];
-	    
+	
 		for (afterPtr = assocPtr->firstAfterPtr; afterPtr != NULL;
 		     afterPtr = afterPtr->nextPtr) {
 		    if (assocPtr->interp == interp) {
@@ -900,7 +908,8 @@ Tcl_AfterObjCmd(clientData, interp, objc, objv)
 			"\" doesn't exist", (char *) NULL);
 		return TCL_ERROR;
 	    }
-	    Tcl_AppendArg(interp, LangCallbackArg(afterPtr->command));
+	    Tcl_ListObjAppendElement(interp, Tcl_GetObjResult(interp),
+               LangCallbackObj(afterPtr->command));
 	    Tcl_AppendElement(interp,
 		    (afterPtr->token == NULL) ? "idle" : "timer");
 	    break;
@@ -1013,7 +1022,7 @@ AfterProc(clientData)
 	Tcl_BackgroundError(interp);
     }
     Tcl_Release((ClientData) interp);
-    
+
     /*
      * Free the memory for the callback.
      */
@@ -1101,3 +1110,5 @@ AfterCleanupProc(clientData, interp)
     }
     ckfree((char *) assocPtr);
 }
+
+#endif
